import { defineConfig, type PresetFactory } from 'unocss'
import {
  presetAttributify,
  presetIcons,
  presetTypography,
  presetUno,
  transformerCompileClass,
  transformerDirectives,
  transformerVariantGroup,
} from 'unocss'
import type { Theme } from 'unocss/preset-uno'
import presetTheme from 'unocss-preset-theme'

export default defineConfig<Theme>({
  theme: {
    colors: {
      text: '#4c4f69',
      subtext: '#5c5f77',
      bg: '#eff1f5',
    },
  },
  presets: [
    presetUno(),
    presetAttributify(),
    presetTypography(),
    presetIcons(),
    presetTheme<Theme>({
      theme: {
        'catppuccin-latte': {
          colors: {
            text: '#4c4f69',
            subtext: '#5c5f77',
            bg: '#eff1f5',
          },
        },
        'catppuccin-frappe': {
          colors: {
            text: '#c6d0f5',
            subtext: '#b5bfe2',
            bg: '#303446',
          },
        },
        'catppuccin-macchiato': {
          colors: {
            text: '#cad3f5',
            subtext: '#b8c0e0',
            bg: '#24273a',
          },
        },
        'catppuccin-mocha': {
          colors: {
            text: '#cdd6f4',
            subtext: '#bac2de',
            bg: '#1e1e2e',
          },
        },
      },
    }) as PresetFactory<Theme>,
  ],
  transformers: [transformerDirectives(), transformerVariantGroup(), transformerCompileClass()],
})
